/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx;

import com.google.common.io.Resources;
import com.google.gson.Gson;
import com.keyware.sonar.cxx.rules.SecurityDesignRuleRepository;
import org.sonar.api.server.profile.BuiltInQualityProfilesDefinition;
import org.sonar.cxx.checks.CheckList;
import org.sonarsource.api.sonarlint.SonarLintSide;

import java.io.IOException;
import java.net.URL;
import java.nio.charset.StandardCharsets;
import java.util.List;

/**
 * define built-in profile
 */
@SonarLintSide
public class CxxSonarWayProfile implements BuiltInQualityProfilesDefinition {

    private static String readResource(URL resource) {
        try {
            return Resources.toString(resource, StandardCharsets.UTF_8);
        } catch (IOException e) {
            throw new IllegalStateException("Failed to read: " + resource, e);
        }
    }

    static Profile readProfile() {
        URL resource = CxxSonarWayProfile.class.getResource("/org/sonar/l10n/cxx/rules/cxx/Sonar_way_profile.json");
        return new Gson().fromJson(readResource(resource), Profile.class);
    }

    @Override
    public void define(Context context) {
        var sonarWay = context.createBuiltInQualityProfile("Sonar way", CxxLanguage.KEY);
        Profile jsonProfile = readProfile();
        jsonProfile.ruleKeys.forEach((key) -> {
            sonarWay.activateRule(CheckList.REPOSITORY_KEY, key);
        });
        sonarWay.done();
    }

    static class Profile {

        public String name;
        public List<String> ruleKeys;
    }

}
