/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx.rules.checkers;


import com.keyware.sonar.cxx.CxxFileTesterHelper;
import org.junit.jupiter.api.Test;
import org.sonar.cxx.CxxAstScanner;
import org.sonar.cxx.squidbridge.api.CheckMessage;
import org.sonar.cxx.squidbridge.api.SourceFile;

import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * TODO ConfigurationFileCheckerTest
 *
 * @author WuHaoYang
 * @date 2024/1/19
 */
public class ConfigurationFileCheckerTest {

    @Test
    public void checkDirectory() throws IOException {


        File folder = new File("src/test/resources/com/keyware/sonar/cxx/rules/checkers/configFile"); // 文件夹路径

        File[] files = folder.listFiles(new FilenameFilter() {
            public boolean accept(File dir, String name) {
                return name.endsWith(".yml") || name.endsWith(".ini") || name.endsWith(".properties") ||
                        name.endsWith(".xml") || name.endsWith(".json") || name.endsWith(".conf");
            }
        });

        List<String> problems = new ArrayList<>(); // 存储问题的列表

        for (File file : files) {

            try {
                if (file.isFile()) {
                    var tester = CxxFileTesterHelper.create("configFile/" + file.getName());
                    System.out.println("配置文件名称：" + file.getName());
                    var checker = new ConfigurationFileChecker();
                    SourceFile sourceFile = CxxAstScanner.scanSingleInputFile(tester.asInputFile(), checker);

                    for (CheckMessage message : sourceFile.getCheckMessages()) {
                        if (message.formatDefaultMessage().equals("避免在容易受攻击的地方存储口令")) {
                            problems.add("文件：" + file.getName() + " ,问题：" + message.getDefaultMessage());
                        }
                    }
                }
            } catch (Exception e) {
                System.out.println("在处理文件时遇到问题：" + file.getName());
                e.printStackTrace();
            }
        }

        for (String problem : problems) {
            System.out.println(problem);
        }
    }


}
