/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：信息安全性设计准则检查插件
 * 项目描述：用于检查源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */

package com.keyware.sonar.cxx.rules.checkers;

import com.keyware.sonar.cxx.CxxFileTesterHelper;
import org.junit.jupiter.api.Test;
import org.sonar.api.batch.fs.InputFile;
import org.sonar.cxx.CxxAstScanner;
import org.sonar.cxx.config.CxxSquidConfiguration;
import org.sonar.cxx.squidbridge.api.SourceCode;
import org.sonar.cxx.squidbridge.api.SourceProject;
import org.sonar.cxx.squidbridge.indexer.QueryByType;

import java.io.IOException;
import java.util.Collection;
import java.util.Set;

import static org.assertj.core.api.Assertions.assertThat;

/**
 * 测试规则：应通过用户名口令、数字证书等其他手段对主机身份进行鉴别
 *
 * @author GuoXin
 * @date 2024/1/24
 */
public class HostIdentityVerifyCheckerTest {
    @Test
    public void checkTest() throws IOException {
        var checker = new HostIdentityVerifyChecker();
        var tester = CxxFileTesterHelper.create("HostIdentityVerifyChecker.cc");
        var scanner = CxxAstScanner.create(new CxxSquidConfiguration(), checker);
        Set<InputFile> inputFiles = Set.of(tester.asInputFile());
        scanner.scanInputFiles(inputFiles);
        Collection<SourceCode> squidSourceFiles = scanner.getIndex().search(new QueryByType(SourceProject.class));
        assertThat(squidSourceFiles).size().isEqualTo(1);
        squidSourceFiles.forEach(sourceCode -> {
            assertThat(sourceCode.getCheckMessages()).size().isEqualTo(1);
        });
    }
}
